@@ -1,6 +1,6 @@
 from .base import APIEndpoint
 
-from cloudspot.models.artikels import Artikels
+from cloudspot.models.artikels import Artikels, Artikel
 
 class ArtikelMethods(APIEndpoint):
 
@@ -14,4 +14,13 @@ class ArtikelMethods(APIEndpoint):
         if status != 200: return Artikels().parseError(respJson)
         artikels = Artikels().parse(respJson['data'])
         
-        return artikels
\ No newline at end of file
+        return artikels
+    
+    def get(self, id, fields=None):
+        data = { 'id' : id }
+        status, headers, respJson = self.api.get(self.endpoint, data)
+        
+        if status != 200: return Artikels().parseError(respJson)
+        artikel = Artikel().parse(respJson['data'][0])
+        
+        return artikel
\ No newline at end of file
