@@ -30,6 +30,8 @@ class Artikel(BaseModel):
         id=None,
         naam=None,
         beschrijving=None,
+        merk=None,
+        categorie=None,
         SKU=None,
         voorraad_bijhouden=None,
         op_voorraad=None,
@@ -51,6 +53,8 @@ class Artikel(BaseModel):
         self.id = id
         self.naam = naam
         self.beschrijving = beschrijving
+        self.merk = merk
+        self.categorie = categorie
         self.SKU = SKU
         self.voorraad_bijhouden = voorraad_bijhouden
         self.op_voorraad = op_voorraad
